==> apache-bigtop-manager-1.0.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/zh_CN/common.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export default {
  prev: '上一步',
  next: '下一步',
  done: '完成',
  save: '保存',
  exit: '退出',
  action: '操作',
  operation: '操作',
  status: '状态',
  healthy: '健康',
  unhealthy: '不健康',
  unknown: '未知',
  success: '正常',
  failed: '异常',
  edit: '编辑',
  delete: '删除',
  remove: '移除{0}',
  bulk_remove: '批量删除',
  batch_operation: '批量操作',
  rename: '重命名',
  disable: '停用',
  enable: '使用',
  submit: '提交',
  retry: '重试',
  cancel: '取消',
  confirm: '确认',
  exit_confirm: '确定要退出吗？',
  install: '安装',
  installing: '安装中...',
  finish: '完成',
  more: '更多',
  view_all: '查看全部',
  select_tips: '请选择',
  name: '名称',
  version: '版本',
  desc: '描述',
  os: '系统',
  arch: '架构',
  base_url: '地址',
  cluster: '集群',
  host: '主机',
  service: '服务',
  stack: '组件栈',
  component: '组件',
  componentname: '组件名',
  quick_link: '快速链接',
  no_link: '无链接',
  stage: '阶段',
  search: '搜索',
  required: '需重启',
  not_required: '无需重启',
  progress: '进度',
  created: '创建成功',
  status_change_success: '状态更新成功',
  test_success: '测试成功',
  update_success: '更新成功',
  update_fail: '更新失败',
  error_unknown: '未知错误',
  error_network: '网络错误',
  error_timeout: '请求超时',
  desc_404: '抱歉，您查看的页面不存在',
  back_home: '返回首页',
  create_time: '创建时间',
  update_time: '更新时间',
  notification: '通知',
  copy: '复制',
  copied: '已复制',
  download: '下载',
  copy_fail: '复制失败',
  delete_success: '删除成功',
  delete_fail: '删除失败',
  delete_confirm_title: '删除确认',
  delete_confirm_content: '删除后无法恢复，确定要删除 {0} 吗？',
  no_options: '暂无选项',
  loading_text_verifying: '校验中',
  enter_error: '请输入{0}',
  select_error: '请选择{0}',
  add_error: '请添加{0}',
  delete_msg: '确认要删除该记录吗？',
  restore_msg: '确认要恢复该记录吗？',
  delete_msgs: '确认要删除这些记录吗？',
  delete_empty: '请选择需要删除的记录',
  total: '共{0}条数据',
  note: '注: 源地址的改动对所有集群生效。',
  upload_file: '上传文件',
  file_type_error: '只能上传文本文件！',
  file_size_error: '文件大小不能超过 10KB！',
  upload_success: '文件上传成功！',
  upload_failed: '文件上传失败！',
  password_not_match: '密码不一致。',
  overview: '概览',
  user: '用户',
  job: '作业',
  start: '启动{0}',
  restart: '重启{0}',
  stop: '停止{0}',
  add: '添加{0}',
  success_msg: '添加成功',
  reset: '重置',
  configs: '配置',
  more_operations: '其他操作',
  ok: '确认',
  yes: '是',
  no: '否',
  all: '全部',
  disabled: '关闭',
  restore: '恢复',
  selected: '选中',
  feature_not_supported: '功能暂不支持'
}

==> apache-bigtop-manager-1.1.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/zh_CN/common.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export default {
  prev: '上一步',
  next: '下一步',
  done: '完成',
  save: '保存',
  exit: '退出',
  action: '操作',
  operation: '操作',
  operate_success: '操作成功',
  status: '状态',
  healthy: '健康',
  unhealthy: '不健康',
  unknown: '未知',
  success: '正常',
  failed: '异常',
  edit: '编辑',
  delete: '删除{0}',
  remove: '移除{0}',
  bulk_remove: '批量删除',
  batch_operation: '批量操作',
  rename: '重命名',
  disable: '停用',
  enable: '使用',
  submit: '提交',
  retry: '重试',
  cancel: '取消',
  confirm: '确认',
  exit_confirm: '确定要退出吗？',
  install: '安装',
  installing: '安装中...',
  finish: '完成',
  more: '更多',
  view_all: '查看全部',
  select_tips: '请选择',
  name: '名称',
  version: '版本',
  desc: '描述',
  os: '系统',
  arch: '架构',
  cluster: '集群',
  host: '主机',
  service: '服务',
  stack: '组件栈',
  component: '组件',
  componentname: '组件名',
  quick_link: '快速链接',
  no_link: '无链接',
  stage: '阶段',
  search: '搜索',
  required: '需重启',
  not_required: '无需重启',
  progress: '进度',
  created: '创建成功',
  status_change_success: '状态更新成功',
  test_success: '测试成功',
  update_success: '更新成功',
  update_fail: '更新失败',
  error_unknown: '未知错误',
  error_network: '网络错误',
  error_timeout: '请求超时',
  desc_404: '抱歉，您查看的页面不存在',
  back_home: '返回首页',
  create_time: '创建时间',
  update_time: '更新时间',
  notification: '通知',
  copy: '复制',
  copied: '已复制',
  download: '下载',
  copy_fail: '复制失败',
  delete_success: '删除成功',
  delete_fail: '删除失败',
  delete_confirm_title: '删除确认',
  delete_confirm_content: '删除后无法恢复，确定要删除 {0} 吗？',
  no_options: '暂无选项',
  loading_text_verifying: '校验中',
  enter_error: '请输入{0}',
  select_error: '请选择{0}',
  add_error: '请添加{0}',
  delete_msg: '确认要删除该记录吗？',
  restore_msg: '确认要恢复该记录吗？',
  delete_msgs: '确认要删除这些记录吗？',
  delete_empty: '请选择需要删除的记录',
  total: '共{0}条数据',
  upload_file: '上传文件',
  file_type_error: '只能上传文本文件！',
  file_size_error: '文件大小不能超过 10KB！',
  upload_success: '文件上传成功！',
  upload_failed: '文件上传失败！',
  password_not_match: '密码不一致。',
  overview: '概览',
  user: '用户',
  job: '作业',
  start: '启动{0}',
  restart: '重启{0}',
  stop: '停止{0}',
  add: '添加{0}',
  success_msg: '添加成功',
  reset: '重置',
  configs: '配置',
  more_operations: '其他操作',
  ok: '确认',
  yes: '是',
  no: '否',
  all: '全部',
  disabled: '关闭',
  restore: '恢复',
  selected: '选中',
  feature_not_supported: '功能暂不支持',
  installing_exit_confirm_content: '正在安装中，退出页面将导致安装失败。是否确定退出？',
  confirm_action: '确定要{action} {target} 吗？',
  confirm_comp_action: '确定要{action}选中的组件吗？'
}
